==> openshift-model-config-6.9.1-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TLSSecurityProfileFluent<A extends TLSSecurityProfileFluent<A>> extends BaseFluent<A>{
  public TLSSecurityProfileFluent() {
  }
  
  public TLSSecurityProfileFluent(TLSSecurityProfile instance) {
    this.copyInstance(instance);
  }
  private CustomTLSProfileBuilder custom;
  private IntermediateTLSProfileBuilder intermediate;
  private ModernTLSProfileBuilder modern;
  private OldTLSProfileBuilder old;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TLSSecurityProfile instance) {
    instance = (instance != null ? instance : new TLSSecurityProfile());
    if (instance != null) {
          this.withCustom(instance.getCustom());
          this.withIntermediate(instance.getIntermediate());
          this.withModern(instance.getModern());
          this.withOld(instance.getOld());
          this.withType(instance.getType());
          this.withCustom(instance.getCustom());
          this.withIntermediate(instance.getIntermediate());
          this.withModern(instance.getModern());
          this.withOld(instance.getOld());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public CustomTLSProfile buildCustom() {
    return this.custom != null ? this.custom.build() : null;
  }
  
  public A withCustom(CustomTLSProfile custom) {
    this._visitables.remove(this.custom);
    if (custom != null) {
        this.custom = new CustomTLSProfileBuilder(custom);
        this._visitables.get("custom").add(this.custom);
    } else {
        this.custom = null;
        this._visitables.get("custom").remove(this.custom);
    }
    return (A) this;
  }
  
  public boolean hasCustom() {
    return this.custom != null;
  }
  
  public CustomNested<A> withNewCustom() {
    return new CustomNested(null);
  }
  
  public CustomNested<A> withNewCustomLike(CustomTLSProfile item) {
    return new CustomNested(item);
  }
  
  public CustomNested<A> editCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(null));
  }
  
  public CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(new CustomTLSProfileBuilder().build()));
  }
  
  public CustomNested<A> editOrNewCustomLike(CustomTLSProfile item) {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(item));
  }
  
  public IntermediateTLSProfile buildIntermediate() {
    return this.intermediate != null ? this.intermediate.build() : null;
  }
  
  public A withIntermediate(IntermediateTLSProfile intermediate) {
    this._visitables.remove(this.intermediate);
    if (intermediate != null) {
        this.intermediate = new IntermediateTLSProfileBuilder(intermediate);
        this._visitables.get("intermediate").add(this.intermediate);
    } else {
        this.intermediate = null;
        this._visitables.get("intermediate").remove(this.intermediate);
    }
    return (A) this;
  }
  
  public boolean hasIntermediate() {
    return this.intermediate != null;
  }
  
  public IntermediateNested<A> withNewIntermediate() {
    return new IntermediateNested(null);
  }
  
  public IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item) {
    return new IntermediateNested(item);
  }
  
  public IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(null));
  }
  
  public IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(new IntermediateTLSProfileBuilder().build()));
  }
  
  public IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item) {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(item));
  }
  
  public ModernTLSProfile buildModern() {
    return this.modern != null ? this.modern.build() : null;
  }
  
  public A withModern(ModernTLSProfile modern) {
    this._visitables.remove(this.modern);
    if (modern != null) {
        this.modern = new ModernTLSProfileBuilder(modern);
        this._visitables.get("modern").add(this.modern);
    } else {
        this.modern = null;
        this._visitables.get("modern").remove(this.modern);
    }
    return (A) this;
  }
  
  public boolean hasModern() {
    return this.modern != null;
  }
  
  public ModernNested<A> withNewModern() {
    return new ModernNested(null);
  }
  
  public ModernNested<A> withNewModernLike(ModernTLSProfile item) {
    return new ModernNested(item);
  }
  
  public ModernNested<A> editModern() {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(null));
  }
  
  public ModernNested<A> editOrNewModern() {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(new ModernTLSProfileBuilder().build()));
  }
  
  public ModernNested<A> editOrNewModernLike(ModernTLSProfile item) {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(item));
  }
  
  public OldTLSProfile buildOld() {
    return this.old != null ? this.old.build() : null;
  }
  
  public A withOld(OldTLSProfile old) {
    this._visitables.remove(this.old);
    if (old != null) {
        this.old = new OldTLSProfileBuilder(old);
        this._visitables.get("old").add(this.old);
    } else {
        this.old = null;
        this._visitables.get("old").remove(this.old);
    }
    return (A) this;
  }
  
  public boolean hasOld() {
    return this.old != null;
  }
  
  public OldNested<A> withNewOld() {
    return new OldNested(null);
  }
  
  public OldNested<A> withNewOldLike(OldTLSProfile item) {
    return new OldNested(item);
  }
  
  public OldNested<A> editOld() {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(null));
  }
  
  public OldNested<A> editOrNewOld() {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(new OldTLSProfileBuilder().build()));
  }
  
  public OldNested<A> editOrNewOldLike(OldTLSProfile item) {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TLSSecurityProfileFluent that = (TLSSecurityProfileFluent) o;
    if (!java.util.Objects.equals(custom, that.custom)) return false;
    if (!java.util.Objects.equals(intermediate, that.intermediate)) return false;
    if (!java.util.Objects.equals(modern, that.modern)) return false;
    if (!java.util.Objects.equals(old, that.old)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (intermediate != null) { sb.append("intermediate:"); sb.append(intermediate + ","); }
    if (modern != null) { sb.append("modern:"); sb.append(modern + ","); }
    if (old != null) { sb.append("old:"); sb.append(old + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNested<N> extends CustomTLSProfileFluent<CustomNested<N>> implements Nested<N>{
    CustomNested(CustomTLSProfile item) {
      this.builder = new CustomTLSProfileBuilder(this, item);
    }
    CustomTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withCustom(builder.build());
    }
    
    public N endCustom() {
      return and();
    }
    
  
  }
  public class IntermediateNested<N> extends IntermediateTLSProfileFluent<IntermediateNested<N>> implements Nested<N>{
    IntermediateNested(IntermediateTLSProfile item) {
      this.builder = new IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withIntermediate(builder.build());
    }
    
    public N endIntermediate() {
      return and();
    }
    
  
  }
  public class ModernNested<N> extends ModernTLSProfileFluent<ModernNested<N>> implements Nested<N>{
    ModernNested(ModernTLSProfile item) {
      this.builder = new ModernTLSProfileBuilder(this, item);
    }
    ModernTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withModern(builder.build());
    }
    
    public N endModern() {
      return and();
    }
    
  
  }
  public class OldNested<N> extends OldTLSProfileFluent<OldNested<N>> implements Nested<N>{
    OldNested(OldTLSProfile item) {
      this.builder = new OldTLSProfileBuilder(this, item);
    }
    OldTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withOld(builder.build());
    }
    
    public N endOld() {
      return and();
    }
    
  
  }

}

==> openshift-model-config-6.10.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TLSSecurityProfileFluent<A extends TLSSecurityProfileFluent<A>> extends BaseFluent<A>{
  public TLSSecurityProfileFluent() {
  }
  
  public TLSSecurityProfileFluent(TLSSecurityProfile instance) {
    this.copyInstance(instance);
  }
  private CustomTLSProfileBuilder custom;
  private IntermediateTLSProfileBuilder intermediate;
  private ModernTLSProfileBuilder modern;
  private OldTLSProfileBuilder old;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TLSSecurityProfile instance) {
    instance = (instance != null ? instance : new TLSSecurityProfile());
    if (instance != null) {
          this.withCustom(instance.getCustom());
          this.withIntermediate(instance.getIntermediate());
          this.withModern(instance.getModern());
          this.withOld(instance.getOld());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public CustomTLSProfile buildCustom() {
    return this.custom != null ? this.custom.build() : null;
  }
  
  public A withCustom(CustomTLSProfile custom) {
    this._visitables.remove("custom");
    if (custom != null) {
        this.custom = new CustomTLSProfileBuilder(custom);
        this._visitables.get("custom").add(this.custom);
    } else {
        this.custom = null;
        this._visitables.get("custom").remove(this.custom);
    }
    return (A) this;
  }
  
  public boolean hasCustom() {
    return this.custom != null;
  }
  
  public CustomNested<A> withNewCustom() {
    return new CustomNested(null);
  }
  
  public CustomNested<A> withNewCustomLike(CustomTLSProfile item) {
    return new CustomNested(item);
  }
  
  public CustomNested<A> editCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(null));
  }
  
  public CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(new CustomTLSProfileBuilder().build()));
  }
  
  public CustomNested<A> editOrNewCustomLike(CustomTLSProfile item) {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(item));
  }
  
  public IntermediateTLSProfile buildIntermediate() {
    return this.intermediate != null ? this.intermediate.build() : null;
  }
  
  public A withIntermediate(IntermediateTLSProfile intermediate) {
    this._visitables.remove("intermediate");
    if (intermediate != null) {
        this.intermediate = new IntermediateTLSProfileBuilder(intermediate);
        this._visitables.get("intermediate").add(this.intermediate);
    } else {
        this.intermediate = null;
        this._visitables.get("intermediate").remove(this.intermediate);
    }
    return (A) this;
  }
  
  public boolean hasIntermediate() {
    return this.intermediate != null;
  }
  
  public IntermediateNested<A> withNewIntermediate() {
    return new IntermediateNested(null);
  }
  
  public IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item) {
    return new IntermediateNested(item);
  }
  
  public IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(null));
  }
  
  public IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(new IntermediateTLSProfileBuilder().build()));
  }
  
  public IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item) {
    return withNewIntermediateLike(java.util.Optional.ofNullable(buildIntermediate()).orElse(item));
  }
  
  public ModernTLSProfile buildModern() {
    return this.modern != null ? this.modern.build() : null;
  }
  
  public A withModern(ModernTLSProfile modern) {
    this._visitables.remove("modern");
    if (modern != null) {
        this.modern = new ModernTLSProfileBuilder(modern);
        this._visitables.get("modern").add(this.modern);
    } else {
        this.modern = null;
        this._visitables.get("modern").remove(this.modern);
    }
    return (A) this;
  }
  
  public boolean hasModern() {
    return this.modern != null;
  }
  
  public ModernNested<A> withNewModern() {
    return new ModernNested(null);
  }
  
  public ModernNested<A> withNewModernLike(ModernTLSProfile item) {
    return new ModernNested(item);
  }
  
  public ModernNested<A> editModern() {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(null));
  }
  
  public ModernNested<A> editOrNewModern() {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(new ModernTLSProfileBuilder().build()));
  }
  
  public ModernNested<A> editOrNewModernLike(ModernTLSProfile item) {
    return withNewModernLike(java.util.Optional.ofNullable(buildModern()).orElse(item));
  }
  
  public OldTLSProfile buildOld() {
    return this.old != null ? this.old.build() : null;
  }
  
  public A withOld(OldTLSProfile old) {
    this._visitables.remove("old");
    if (old != null) {
        this.old = new OldTLSProfileBuilder(old);
        this._visitables.get("old").add(this.old);
    } else {
        this.old = null;
        this._visitables.get("old").remove(this.old);
    }
    return (A) this;
  }
  
  public boolean hasOld() {
    return this.old != null;
  }
  
  public OldNested<A> withNewOld() {
    return new OldNested(null);
  }
  
  public OldNested<A> withNewOldLike(OldTLSProfile item) {
    return new OldNested(item);
  }
  
  public OldNested<A> editOld() {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(null));
  }
  
  public OldNested<A> editOrNewOld() {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(new OldTLSProfileBuilder().build()));
  }
  
  public OldNested<A> editOrNewOldLike(OldTLSProfile item) {
    return withNewOldLike(java.util.Optional.ofNullable(buildOld()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TLSSecurityProfileFluent that = (TLSSecurityProfileFluent) o;
    if (!java.util.Objects.equals(custom, that.custom)) return false;
    if (!java.util.Objects.equals(intermediate, that.intermediate)) return false;
    if (!java.util.Objects.equals(modern, that.modern)) return false;
    if (!java.util.Objects.equals(old, that.old)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (intermediate != null) { sb.append("intermediate:"); sb.append(intermediate + ","); }
    if (modern != null) { sb.append("modern:"); sb.append(modern + ","); }
    if (old != null) { sb.append("old:"); sb.append(old + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNested<N> extends CustomTLSProfileFluent<CustomNested<N>> implements Nested<N>{
    CustomNested(CustomTLSProfile item) {
      this.builder = new CustomTLSProfileBuilder(this, item);
    }
    CustomTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withCustom(builder.build());
    }
    
    public N endCustom() {
      return and();
    }
    
  
  }
  public class IntermediateNested<N> extends IntermediateTLSProfileFluent<IntermediateNested<N>> implements Nested<N>{
    IntermediateNested(IntermediateTLSProfile item) {
      this.builder = new IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withIntermediate(builder.build());
    }
    
    public N endIntermediate() {
      return and();
    }
    
  
  }
  public class ModernNested<N> extends ModernTLSProfileFluent<ModernNested<N>> implements Nested<N>{
    ModernNested(ModernTLSProfile item) {
      this.builder = new ModernTLSProfileBuilder(this, item);
    }
    ModernTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withModern(builder.build());
    }
    
    public N endModern() {
      return and();
    }
    
  
  }
  public class OldNested<N> extends OldTLSProfileFluent<OldNested<N>> implements Nested<N>{
    OldNested(OldTLSProfile item) {
      this.builder = new OldTLSProfileBuilder(this, item);
    }
    OldTLSProfileBuilder builder;
    
    public N and() {
      return (N) TLSSecurityProfileFluent.this.withOld(builder.build());
    }
    
    public N endOld() {
      return and();
    }
    
  
  }

}
